==> haskell-attoparsec-iso8601-1.1.0.1-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.0.1
visibility:           public
id:                   attoparsec-iso8601-1.1.0.1-AT0uN0uBMEuCuJkmEutdFK
key:                  attoparsec-iso8601-1.1.0.1-AT0uN0uBMEuCuJkmEutdFK
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  67916c13f38255e1a9b4779ee7a96678
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.0.1-AT0uN0uBMEuCuJkmEutdFK
depends:
    attoparsec-0.14.4-6kRuW0kw4gG3rg1QrsDffs base-4.17.2.1
    integer-conversion-0.1.1-5jkOTqGkUHLLLzen6u95UZ text-2.0.2
    time-1.12.2 time-compat-1.9.7-Lp4yHSXOXnm7NwA0QeuSsu

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.1.0.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.0.1
visibility:           public
id:                   attoparsec-iso8601-1.1.0.1-AZsFoGkC58gCboBq4WgAs7
key:                  attoparsec-iso8601-1.1.0.1-AZsFoGkC58gCboBq4WgAs7
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  4d57218023b3db136d78787cf1ab8daa
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/attoparsec-iso8601-1.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.0.1-AZsFoGkC58gCboBq4WgAs7
depends:
    attoparsec-0.14.4-D7CECqktDgS2fYWStxbJq3 base-4.17.2.1
    integer-conversion-0.1.1-4dwMy9nHkQx7QTjMWLYoI0 text-2.0.2
    time-1.12.2 time-compat-1.9.7-ba1m3hcox9GPef9U1a5Ja

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
